@@ -9,19 +9,20 @@ import os
 from compare_output import parse_mopac_out_file, compare_mopac_out_file
 
 # make a local copy of the input & other necessary files
-for file in argv[3:]:
+for file in argv[4:]:
    copyfile(os.path.join(argv[1],file),file)
 
 # run MOPAC in the local directory
 try:
-    subprocess.run([argv[2],argv[3]], check=True)
-except subprocess.CalledProcessError as err:
+    subprocess.run([argv[2],argv[4]], check=True)
+except subprocess.SubprocessError as err:
     print("In attempting to run: ", err.cmd)
     print("stdout: ", err.stdout)
     print("stderr: ", err.stderr)
+    raise
 
 # only compare ".out" output files that have the same name as ".mop" or ".ent" input files
-out_name = argv[3][:-3]+'out'
+out_name = argv[4][:-3]+'out'
 ref_path = os.path.join(argv[1],out_name)
 
 # parse the 2 output files that we are comparing
@@ -29,4 +30,4 @@ ref_line, ref_list = parse_mopac_out_file(ref_path)
 out_line, out_list = parse_mopac_out_file(out_name)
 
 # Run the comparison
-compare_mopac_out_file(out_line, out_list, ref_line, ref_list)
+compare_mopac_out_file(out_line, out_list, ref_line, ref_list, float(argv[3]))
